@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 9's 2.6.27 kernel.
+# This is a kernel build script for Fedora 11's 2.6.30 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27.25-78.2.56.fc9.src.rpm ]
+if [ ! -r kernel-2.6.30.9-96.fc11.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/9/SRPMS.newkey/kernel-2.6.27.25-78.2.56.fc9.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/11/SRPMS/kernel-2.6.30.9-96.fc11.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27.25-78.2.56.fc9.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.30.9-96.fc11.src.rpm || die "Can't install source package."
 
-cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090911.tar.gz ]
+cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
+if [ ! -r ccs-patch-1.6.8-20091111.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090911.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20091111.tar.gz || die "Can't download patch."
 fi
 
-cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /usr/src/redhat/SPECS/kernel.spec . || die "Can't copy spec file."
+cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
+cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel.spec	2009-06-19 01:03:39.000000000 +0900
-+++ kernel.spec	2009-06-25 17:07:16.000000000 +0900
-@@ -12,7 +12,7 @@
+--- ccs-kernel.spec	2009-11-04 13:23:12.000000000 +0900
++++ ccs-kernel.spec	2009-11-07 08:46:39.895977403 +0900
+@@ -15,7 +15,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
--#% define buildid .local
+-# % define buildid .local
 +%define buildid _tomoyo_1.6.8p1
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
-@@ -411,6 +411,11 @@
+@@ -393,6 +393,11 @@
  # to versions below the minimum
  #
  
@@ -48,16 +48,16 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -439,7 +444,7 @@
+@@ -428,7 +433,7 @@
  # Packages that need to be installed before the kernel is, because the %post
  # scripts use them.
  #
--%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.39-1, kernel-firmware >= %{rpmversion}-%{pkg_release}
-+%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.39-1
+-%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1, kernel-firmware >= %{rpmversion}-%{pkg_release}, /sbin/new-kernel-pkg
++%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1, /sbin/new-kernel-pkg
  
  #
  # This macro does requires, provides, conflicts, obsoletes for a kernel package.
-@@ -467,7 +472,7 @@
+@@ -456,7 +461,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -66,7 +66,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -856,7 +861,7 @@
+@@ -928,7 +933,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -75,18 +75,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1371,6 +1376,10 @@
+@@ -1565,6 +1570,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20090911.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-fedora-9.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20091111.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.30-fedora-11.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1399,6 +1408,9 @@
+@@ -1591,6 +1600,9 @@
  for i in *.config
  do
    mv $i .config
@@ -97,11 +97,10 @@ patch << "EOF" || die "Can't patch spec file."
    make ARCH=$Arch %{oldconfig_target} > /dev/null
    echo "# $Arch" > configs/$i
 EOF
-mv kernel.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
-echo "Edit /tmp/ccs-kernel.spec if needed, and run"
-echo "rpmbuild -bb /tmp/ccs-kernel.spec"
+echo "Edit /root/rpmbuild/SPECS/ccs-kernel.spec if needed, and run"
+echo "rpmbuild -bb /root/rpmbuild/SPECS/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 exit 0
